@@ -11,7 +11,6 @@
 # under the License.
 
 from __future__ import absolute_import
-
 import logging
 
 from django.conf import settings
@@ -59,36 +58,6 @@ class PTG(neutron.NeutronAPIDictWrapper):
         return epg_dict
 
 
-class ExternalPTG(neutron.NeutronAPIDictWrapper):
-
-    """Wrapper for neutron external endpoint group."""
-
-    def get_dict(self):
-        eepg_dict = self._apidict
-        eepg_dict['eepg_id'] = eepg_dict['id']
-        return eepg_dict
-
-
-class ExternalConnectivity(neutron.NeutronAPIDictWrapper):
-
-    """Wrapper for neutron external segment."""
-
-    def get_dict(self):
-        ec_dict = self._apidict
-        ec_dict['ec_id'] = ec_dict['id']
-        return ec_dict
-
-
-class NATPool(neutron.NeutronAPIDictWrapper):
-
-    """Wrapper for neutron nat pool."""
-
-    def get_dict(self):
-        natpool_dict = self._apidict
-        natpool_dict['natpool_id'] = natpool_dict['id']
-        return natpool_dict
-
-
 class Contract(neutron.NeutronAPIDictWrapper):
 
     """Wrapper for neutron policy_rule_set."""
@@ -175,19 +144,10 @@ class ServiceChainInstance(neutron.NeutronAPIDictWrapper):
         return sc_instance_dict
 
 
-class ServiceProfile(neutron.NeutronAPIDictWrapper):
-
-    """Wrapper for neutron service profile."""
-
-    def get_dict(self):
-        sc_profile_dict = self._apidict
-        return sc_profile_dict
-
-
 def policy_target_create(request, **kwargs):
     body = {'policy_target_group': kwargs}
     policy_target = gbpclient(request).create_policy_target_group(
-        body).get('policy_target_group')
+        body).get('endpoint_group')
     return PTG(policy_target)
 
 
@@ -197,24 +157,15 @@ def pt_create(request, **kwargs):
     return PTG(pt)
 
 
-def pt_list(request, tenant_id, **kwargs):
+def pt_list(request, **kwargs):
     policy_targets = gbpclient(request).list_policy_targets(
-        tenant_id=tenant_id, shared=False, **kwargs).get('policy_targets')
-    policy_targets.extend(gbpclient(request).list_policy_targets(
-        shared=True, **kwargs).get('policy_targets'))
+        **kwargs).get('policy_targets')
     return [PT(pt) for pt in policy_targets]
 
 
-def pt_delete(request, pt_id):
-    gbpclient(request).delete_policy_target(pt_id)
-
-
-def policy_target_list(request, tenant_id, **kwargs):
+def policy_target_list(request, **kwargs):
     policy_targets = gbpclient(request).list_policy_target_groups(
-        tenant_id=tenant_id, shared=False, **kwargs).get(
-            'policy_target_groups')
-    policy_targets.extend(gbpclient(request).list_policy_target_groups(
-        shared=True, **kwargs).get('policy_target_groups'))
+        **kwargs).get('policy_target_groups')
     return [PTG(policy_target) for policy_target in policy_targets]
 
 
@@ -235,38 +186,6 @@ def policy_target_update(request, policy_target_id, **kwargs):
     return PTG(policy_target)
 
 
-def ext_policy_target_create(request, **kwargs):
-    body = {'external_policy': kwargs}
-    policy_target = gbpclient(request).create_external_policy(
-        body).get('external_policy')
-    return ExternalPTG(policy_target)
-
-
-def ext_policy_target_list(request, tenant_id, **kwargs):
-    policy_targets = gbpclient(request).list_external_policies(
-        tenant_id=tenant_id, shared=False, **kwargs).get('external_policies')
-    policy_targets.extend(gbpclient(request).list_external_policies(
-        shared=True, **kwargs).get('external_policies'))
-    return [ExternalPTG(policy_target) for policy_target in policy_targets]
-
-
-def ext_policy_target_get(request, ext_policy_target_id):
-    policy_target = gbpclient(request).show_external_policy(
-        ext_policy_target_id).get('external_policy')
-    return ExternalPTG(policy_target)
-
-
-def ext_policy_target_delete(request, ext_policy_target_id):
-    gbpclient(request).delete_external_policy(ext_policy_target_id)
-
-
-def ext_policy_target_update(request, ext_policy_target_id, **kwargs):
-    body = {'external_policy': kwargs}
-    policy_target = gbpclient(request).update_external_policy(
-        ext_policy_target_id, body).get('external_policy')
-    return ExternalPTG(policy_target)
-
-
 def policy_rule_set_create(request, **kwargs):
     body = {'policy_rule_set': kwargs}
     policy_rule_set = gbpclient(request).create_policy_rule_set(
@@ -274,11 +193,9 @@ def policy_rule_set_create(request, **kwargs):
     return Contract(policy_rule_set)
 
 
-def policy_rule_set_list(request, tenant_id, **kwargs):
+def policy_rule_set_list(request, **kwargs):
     policy_rule_sets = gbpclient(request).list_policy_rule_sets(
-        tenant_id=tenant_id, shared=False, **kwargs).get('policy_rule_sets')
-    policy_rule_sets.extend(gbpclient(request).list_policy_rule_sets(
-        shared=True, **kwargs).get('policy_rule_sets'))
+        **kwargs).get('policy_rule_sets')
     return [Contract(policy_rule_set) for policy_rule_set in policy_rule_sets]
 
 
@@ -313,11 +230,9 @@ def policyrule_update(request, prid, **kwargs):
     return PolicyRule(policy_rule)
 
 
-def policyrule_list(request, tenant_id, **kwargs):
-    policyrules = gbpclient(request).list_policy_rules(tenant_id=tenant_id,
-        shared=False, **kwargs).get('policy_rules')
-    policyrules.extend(gbpclient(request).list_policy_rules(shared=True,
-        **kwargs).get('policy_rules'))
+def policyrule_list(request, **kwargs):
+    policyrules = gbpclient(request).list_policy_rules(
+        **kwargs).get('policy_rules')
     return [PolicyRule(pr) for pr in policyrules]
 
 
@@ -328,11 +243,9 @@ def policyclassifier_create(request, **kwargs):
     return PolicyClassifier(classifier)
 
 
-def policyclassifier_list(request, tenant_id, **kwargs):
+def policyclassifier_list(request, **kwargs):
     classifiers = gbpclient(request).list_policy_classifiers(
-        tenant_id=tenant_id, shared=False, **kwargs).get('policy_classifiers')
-    classifiers.extend(gbpclient(request).list_policy_classifiers(shared=True,
-        **kwargs).get('policy_classifiers'))
+        **kwargs).get('policy_classifiers')
     return [PolicyClassifier(pc) for pc in classifiers]
 
 
@@ -343,11 +256,9 @@ def policyaction_create(request, **kwargs):
     return PolicyAction(action)
 
 
-def policyaction_list(request, tenant_id, **kwargs):
-    actions = gbpclient(request).list_policy_actions(tenant_id=tenant_id,
-        shared=False, **kwargs).get('policy_actions')
-    actions.extend(gbpclient(request).list_policy_actions(shared=True,
-        **kwargs).get('policy_actions'))
+def policyaction_list(request, **kwargs):
+    actions = gbpclient(request).list_policy_actions(
+        **kwargs).get('policy_actions')
     return [PolicyAction(pa) for pa in actions]
 
 
@@ -395,96 +306,22 @@ def policyclassifier_update(request, pc_id, **kwargs):
     return PolicyClassifier(classifier)
 
 
-def l3policy_list(request, tenant_id, **kwargs):
-    policies = gbpclient(request).list_l3_policies(tenant_id=tenant_id,
-        shared=False, **kwargs).get('l3_policies')
-    policies.extend(gbpclient(request).list_l3_policies(shared=True,
-        **kwargs).get('l3_policies'))
+def l3policy_list(request, **kwargs):
+    policies = gbpclient(request).list_l3_policies(**kwargs).get('l3_policies')
     return [L2Policy(item) for item in policies]
 
 
-def l2policy_list(request, tenant_id, **kwargs):
-    policies = gbpclient(request).list_l2_policies(tenant_id=tenant_id,
-        shared=False, **kwargs).get('l2_policies')
-    policies.extend(gbpclient(request).list_l2_policies(shared=True,
-        **kwargs).get('l2_policies'))
+def l2policy_list(request, **kwargs):
+    policies = gbpclient(request).list_l2_policies(**kwargs).get('l2_policies')
     return [L2Policy(item) for item in policies]
 
 
-def networkservicepolicy_list(request, tenant_id, **kwargs):
+def networkservicepolicy_list(request, **kwargs):
     policies = gbpclient(request).list_network_service_policies(
-        tenant_id=tenant_id, shared=False, **kwargs).get(
-            'network_service_policies')
-    policies.extend(gbpclient(request).list_network_service_policies(
-        shared=True, **kwargs).get('network_service_policies'))
+        **kwargs).get('network_service_policies')
     return [NetworkServicePolicy(item) for item in policies]
 
 
-def externalconnectivity_list(request, tenant_id, **kwargs):
-    external_connectivities = gbpclient(request).list_external_segments(
-        tenant_id=tenant_id, shared=False, **kwargs).get('external_segments')
-    external_connectivities.extend(gbpclient(request).list_external_segments(
-        shared=True, **kwargs).get('external_segments'))
-    return [ExternalConnectivity(external_connectivity)
-        for external_connectivity in external_connectivities]
-
-
-def natpool_list(request, tenant_id, **kwargs):
-    nat_pools = gbpclient(request).list_nat_pools(
-        tenant_id=tenant_id, shared=False, **kwargs).get('nat_pools')
-    nat_pools.extend(gbpclient(request).list_nat_pools(
-        shared=True, **kwargs).get('nat_pools'))
-    return [NATPool(nat_pool) for nat_pool in nat_pools]
-
-
-def create_natpool(request, **kwargs):
-    body = {'nat_pool': kwargs}
-    np = gbpclient(request).create_nat_pool(
-        body).get('nat_pool')
-    return NATPool(np)
-
-
-def get_natpool(request, nat_pool_id):
-    np = gbpclient(request).show_nat_pool(
-        nat_pool_id).get('nat_pool')
-    return NATPool(np)
-
-
-def delete_natpool(request, nat_pool_id, **kwargs):
-    gbpclient(request).delete_nat_pool(nat_pool_id)
-
-
-def update_natpool(request, nat_pool_id, **kwargs):
-    body = {'nat_pool': kwargs}
-    np = gbpclient(request).update_nat_pool(
-        nat_pool_id, body).get('nat_pool')
-    return NATPool(np)
-
-
-def create_externalconnectivity(request, **kwargs):
-    body = {'external_segment': kwargs}
-    es = gbpclient(request).create_external_segment(
-        body).get('external_segment')
-    return ExternalConnectivity(es)
-
-
-def get_externalconnectivity(request, external_connectivity_id):
-    es = gbpclient(request).show_external_segment(
-        external_connectivity_id).get('external_segment')
-    return ExternalConnectivity(es)
-
-
-def delete_externalconnectivity(request, external_connectivity_id, **kwargs):
-    gbpclient(request).delete_external_segment(external_connectivity_id)
-
-
-def update_externalconnectivity(request, external_connectivity_id, **kwargs):
-    body = {'external_segment': kwargs}
-    ec = gbpclient(request).update_external_segment(
-        external_connectivity_id, body).get('external_segment')
-    return ExternalConnectivity(ec)
-
-
 def create_networkservice_policy(request, **kwargs):
     body = {'network_service_policy': kwargs}
     spolicy = gbpclient(request).create_network_service_policy(
@@ -518,11 +355,6 @@ def l3policy_create(request, **kwargs):
     return gbpclient(request).create_l3_policy(body).get('l3_policy')
 
 
-def l3policy_update(request, pc_id, **kwargs):
-    body = {'l3_policy': kwargs}
-    return gbpclient(request).update_l3_policy(pc_id, body).get('l3_policy')
-
-
 def l3policy_delete(request, policy_id):
     gbpclient(request).delete_l3_policy(policy_id)
 
@@ -547,26 +379,21 @@ def l2policy_delete(request, policy_id):
     gbpclient(request).delete_l2_policy(policy_id)
 
 
-def servicechainnode_list(request, tenant_id, **kwargs):
-    sc_nodes = gbpclient(request).list_servicechain_nodes(tenant_id=tenant_id,
-        shared=False, **kwargs).get('servicechain_nodes')
-    sc_nodes.extend(gbpclient(request).list_servicechain_nodes(shared=True,
-        **kwargs).get('servicechain_nodes'))
+def servicechainnode_list(request, **kwargs):
+    sc_nodes = gbpclient(request).list_servicechain_nodes(
+        **kwargs).get('servicechain_nodes')
     return [ServiceChainNode(item) for item in sc_nodes]
 
 
-def servicechainspec_list(request, tenant_id, **kwargs):
-    sc_specs = gbpclient(request).list_servicechain_specs(tenant_id=tenant_id,
-        shared=False, **kwargs).get('servicechain_specs')
-    sc_specs.extend(gbpclient(request).list_servicechain_specs(shared=True,
-        **kwargs).get('servicechain_specs'))
+def servicechainspec_list(request, **kwargs):
+    sc_specs = gbpclient(request).list_servicechain_specs(
+        **kwargs).get('servicechain_specs')
     return [ServiceChainSpec(item) for item in sc_specs]
 
 
-def servicechaininstance_list(request, tenant_id, **kwargs):
+def servicechaininstance_list(request, **kwargs):
     sc_instances = gbpclient(request).list_servicechain_instances(
-        tenant_id=tenant_id, shared=False, **kwargs).get(
-        'servicechain_instances')
+        **kwargs).get('servicechain_instances')
     return [ServiceChainInstance(item) for item in sc_instances]
 
 
@@ -640,26 +467,3 @@ def update_servicechain_instance(request, scinstance_id, **kwargs):
 
 def delete_servicechain_instance(request, scinstance_id):
     gbpclient(request).delete_servicechain_instance(scinstance_id)
-
-
-def serviceprofile_list(request, **kwargs):
-    sc_profile = gbpclient(request).list_service_profiles(True,
-        **kwargs).get('service_profiles')
-    return [ServiceProfile(item) for item in sc_profile]
-
-
-def get_service_profile(request, service_profile_id):
-    service_profile = gbpclient(request).show_service_profile(
-        service_profile_id).get('service_profile')
-    return ServiceProfile(service_profile)
-
-
-def create_service_profile(request, **kwargs):
-    body = {'service_profile': kwargs}
-    service_profile = gbpclient(request).create_service_profile(
-        body).get('service_profile')
-    return ServiceProfile(service_profile)
-
-
-def delete_service_profile(request, service_profile_id):
-    gbpclient(request).delete_service_profile(service_profile_id)
