@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.urls import reverse_lazy
+from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -19,7 +19,7 @@ from horizon import tabs
 from gbpui import client
 from gbpui import column_filters as gfilters
 
-from gbpui.panels.application_policy import tables
+import tables
 
 PolicyRulesTable = tables.PolicyRulesTable
 PolicyClassifiersTable = tables.PolicyClassifiersTable
@@ -35,8 +35,10 @@ class PolicyActionsTab(tabs.TableTab):
     def get_policyactionstable_data(self):
         actions = []
         try:
-            actions = client.policyaction_list(self.tab_group.request,
-                tenant_id=self.tab_group.request.user.tenant_id)
+            tenant_id = self.request.user.tenant_id
+            actions = client.policyaction_list(
+                self.tab_group.request,
+                tenant_id=tenant_id)
             a = lambda x, y: gfilters.update_policyaction_attributes(x, y)
             actions = [a(self.request, item) for item in actions]
         except Exception as e:
@@ -53,14 +55,18 @@ class PolicyClassifiersTab(tabs.TableTab):
 
     def get_policyclassifierstable_data(self):
         try:
-            classifiers = client.policyclassifier_list(self.tab_group.request,
-                tenant_id=self.tab_group.request.user.tenant_id)
+            tenant_id = self.request.user.tenant_id
+            classifiers = client.policyclassifier_list(
+                self.tab_group.request,
+                tenant_id=tenant_id)
         except Exception:
             classifiers = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve classifier list.'))
-        else:
-            classifiers = gfilters.update_classifier_attributes(classifiers)
+
+        for classifier in classifiers:
+            classifier.set_id_as_name_if_empty()
+
         return classifiers
 
 
@@ -72,8 +78,10 @@ class PolicyRulesTab(tabs.TableTab):
 
     def get_policyrulestable_data(self):
         try:
-            policy_rules = client.policyrule_list(self.tab_group.request,
-                tenant_id=self.tab_group.request.user.tenant_id)
+            tenant_id = self.request.user.tenant_id
+            policy_rules = client.policyrule_list(
+                self.tab_group.request,
+                tenant_id=tenant_id)
             policy_rules = [gfilters.update_policyrule_attributes(
                 self.request, item) for item in policy_rules]
         except Exception:
@@ -96,9 +104,9 @@ class ApplicationPoliciesTab(tabs.TableTab):
     def get_application_policies_table_data(self):
         policy_rule_sets = []
         try:
+            tenant_id = self.request.user.tenant_id
             policy_rule_sets = client.policy_rule_set_list(
-                self.tab_group.request,
-                tenant_id=self.tab_group.request.user.tenant_id)
+                self.tab_group.request, tenant_id=tenant_id)
             policy_rule_sets = [gfilters.update_pruleset_attributes(
                 self.request, item) for item in policy_rule_sets]
         except Exception:
@@ -131,8 +139,7 @@ class PolicyRuleSetDetailsTab(tabs.Tab):
         try:
             policy_rule_set = client.policy_rule_set_get(request, cid)
             rules = client.policyrule_list(
-                request, tenant_id=request.user.tenant_id,
-                policy_rule_set_id=policy_rule_set.id)
+                request, policy_rule_set_id=policy_rule_set.id)
             rules = [
                 item for item in rules if item.id in
                 policy_rule_set.policy_rules]
@@ -186,14 +193,12 @@ class PolicyRulesDetailsTab(tabs.Tab):
         classifiers = []
         try:
             policyrule = client.policyrule_get(request, ruleid)
-            actions = client.policyaction_list(request,
-                tenant_id=request.user.tenant_id, policyrule_id=ruleid)
+            actions = client.policyaction_list(request, policyrule_id=ruleid)
             actions = [
                 item for item in actions if item.id in
                 policyrule.policy_actions]
             classifiers = client.policyclassifier_list(
-                request, tenant_id=request.user.tenant_id,
-                policyrule_id=ruleid)
+                request, policyrule_id=ruleid)
             classifiers = [
                 item for item in classifiers if
                 item.id == policyrule.policy_classifier_id]
@@ -221,8 +226,6 @@ class PolicyClassifierDetailsTab(tabs.Tab):
         pcid = self.tab_group.kwargs['policyclassifier_id']
         try:
             policyclassifier = client.policyclassifier_get(request, pcid)
-            policyclassifier = gfilters.update_classifier_attributes(
-                policyclassifier)
         except Exception:
             exceptions.handle(request,
                               _('Unable to retrieve policy_rule_set details.'),
