@@ -10,8 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.urls import reverse
-from django.utils import html
+from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -21,7 +20,6 @@ from horizon import workflows
 from gbpui import client
 from gbpui import fields
 
-
 ADD_POLICY_ACTION_URL = "horizon:project:application_policy:addpolicyaction"
 ADD_POLICY_CLASSIFIER_URL = "horizon:project:application_policy:"
 ADD_POLICY_CLASSIFIER_URL = ADD_POLICY_CLASSIFIER_URL + "addpolicyclassifier"
@@ -29,21 +27,21 @@ ADD_POLICY_RULE_URL = "horizon:project:application_policy:addpolicyrule"
 
 
 class SelectPolicyRuleAction(workflows.Action):
-    policy_rules = fields.TransferTableField(
+    policy_rules = fields.DynamicMultiChoiceField(
         label=_("Policy Rules"),
         required=False,
         add_item_link=ADD_POLICY_RULE_URL,
-        help_text=_("Create a policy rule set with selected rules.")
-    )
+        help_text=_("Create a policy rule set with selected rules."))
 
-    class Meta(object):
+    class Meta:
         name = _("Rules")
         help_text = _("Select policy rules for your policy rule set.")
 
     def populate_policy_rules_choices(self, request, context):
         try:
+            tenant_id = self.request.user.tenant_id
             rules = client.policyrule_list(request,
-                tenant_id=request.user.tenant_id)
+                                           tenant_id=tenant_id)
             for r in rules:
                 r.set_id_as_name_if_empty()
             rules = sorted(rules,
@@ -77,20 +75,18 @@ class AddContractAction(workflows.Action):
     description = forms.CharField(max_length=80,
                                   label=_("Description"),
                                   required=False)
-    shared = forms.BooleanField(label=_("Shared"),
-                                initial=False, required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(AddContractAction, self).__init__(request, *args, **kwargs)
 
-    class Meta(object):
+    class Meta:
         name = _("Create Policy Rule Set")
         help_text = _("Create a new Policy Rule Set")
 
 
 class AddContractStep(workflows.Step):
     action_class = AddContractAction
-    contributes = ("name", "description", "shared")
+    contributes = ("name", "description")
 
     def contribute(self, data, context):
         context = super(AddContractStep, self).contribute(data, context)
@@ -115,10 +111,6 @@ class AddContract(workflows.Workflow):
 
     def _create_policy_rule_set(self, request, context):
         try:
-            if context.get('name'):
-                context['name'] = html.escape(context['name'])
-            if context.get('description'):
-                context['description'] = html.escape(context['description'])
             return client.policy_rule_set_create(request, **context)
         except Exception as e:
             msg = self.format_status_message(self.failure_message) + str(e)
@@ -126,10 +118,6 @@ class AddContract(workflows.Workflow):
             return False
 
     def handle(self, request, context):
-        if context.get('name'):
-            context['name'] = html.escape(context['name'])
-        if context.get('description'):
-            context['description'] = html.escape(context['description'])
         policy_rule_set = self._create_policy_rule_set(request, context)
         self.object = policy_rule_set
         return policy_rule_set
@@ -142,14 +130,15 @@ class SelectPolicyClassifierAction(workflows.Action):
         help_text=_("Create a policy with selected classifier."),
         add_item_link=ADD_POLICY_CLASSIFIER_URL)
 
-    class Meta(object):
+    class Meta:
         name = _("Classifiers")
         help_text = _("Select classifiers for your policy-rule.")
 
     def populate_classifier_choices(self, request, context):
         try:
+            tenant_id = self.request.user.tenant_id
             classifiers = client.policyclassifier_list(request,
-                tenant_id=request.user.tenant_id)
+                                                       tenant_id=tenant_id)
             for classifier in classifiers:
                 classifier.set_id_as_name_if_empty()
             classifiers = sorted(classifiers,
@@ -164,31 +153,29 @@ class SelectPolicyClassifierAction(workflows.Action):
 
 
 class SelectPolicyActionAction(workflows.Action):
-    actions = fields.TransferTableField(
+    actions = fields.DynamicMultiChoiceField(
         label=_("Policy Action"),
         required=False,
-        add_item_link=ADD_POLICY_ACTION_URL,
-        help_text=_("Create a policy-rule with selected action.")
-    )
+        help_text=_("Create a policy-rule with selected action."),
+        add_item_link=ADD_POLICY_ACTION_URL)
 
-    def __init__(self, request, context, *args, **kwargs):
-        super(SelectPolicyActionAction, self).__init__(
-            request, context, *args, **kwargs
-        )
-
-    class Meta(object):
+    class Meta:
         name = _("actions")
         help_text = _("Select actions for your policy-rule.")
 
     def populate_actions_choices(self, request, context):
         try:
+            tenant_id = self.request.user.tenant_id
             actions = client.policyaction_list(request,
-                tenant_id=request.user.tenant_id)
+                                               tenant_id=tenant_id)
+            action_list = [a.id for a in actions]
             for action in actions:
                 action.set_id_as_name_if_empty()
             actions = sorted(actions,
                              key=lambda action: action.name)
             action_list = [(a.id, a.name) for a in actions]
+            if len(action_list) > 0:
+                self.fields['actions'].initial = action_list[0]
         except Exception as e:
             action_list = []
             exceptions.handle(request,
@@ -229,20 +216,18 @@ class AddPolicyRuleAction(workflows.Action):
     description = forms.CharField(max_length=80,
                                   label=_("Description"),
                                   required=False)
-    shared = forms.BooleanField(label=_("Shared"),
-                                initial=False, required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(AddPolicyRuleAction, self).__init__(request, *args, **kwargs)
 
-    class Meta(object):
+    class Meta:
         name = _("Create Policy-Rule")
         help_text = _("Create a new Policy-Rule")
 
 
 class AddPolicyRuleStep(workflows.Step):
     action_class = AddPolicyRuleAction
-    contributes = ("name", "description", "shared")
+    contributes = ("name", "description")
 
     def contribute(self, data, context):
         context = super(AddPolicyRuleStep, self).contribute(data, context)
@@ -268,10 +253,6 @@ class AddPolicyRule(workflows.Workflow):
 
     def handle(self, request, context):
         try:
-            if context.get('name'):
-                context['name'] = html.escape(context['name'])
-            if context.get('description'):
-                context['description'] = html.escape(context['description'])
             rule = client.policyrule_create(request, **context)
             self.object = rule
             return rule
@@ -298,20 +279,18 @@ class AddClassifierAction(workflows.Action):
         choices=[('in', _('IN')),
                  ('out', _('OUT')),
                  ('bi', _('BI'))])
-    shared = forms.BooleanField(label=_("Shared"),
-                                initial=False, required=False)
 
     def __init__(self, request, *args, **kwargs):
         super(AddClassifierAction, self).__init__(request, *args, **kwargs)
 
-    class Meta(object):
+    class Meta:
         name = _("Create Classifier")
         help_text = _("Create a new Classifier")
 
 
 class AddClassifierStep(workflows.Step):
     action_class = AddClassifierAction
-    contributes = ("name", "protocol", "port_range", "direction", "shared")
+    contributes = ("name", "protocol", "port_range", "direction")
 
     def contribute(self, data, context):
         context = super(AddClassifierStep, self).contribute(data, context)
@@ -332,10 +311,6 @@ class AddPolicyClassifier(workflows.Workflow):
 
     def _create_classifer(self, request, context):
         try:
-            if context.get('name'):
-                context['name'] = html.escape(context['name'])
-            if context.get('description'):
-                context['description'] = html.escape(context['description'])
             client.policyclassifier_create(request, **context)
             return True
         except Exception as e:
@@ -344,10 +319,6 @@ class AddPolicyClassifier(workflows.Workflow):
             return False
 
     def handle(self, request, context):
-        if context.get('name'):
-            context['name'] = html.escape(context['name'])
-        if context.get('description'):
-            context['description'] = html.escape(context['description'])
         classifier = self._create_classifer(request, context)
         if not classifier:
             return False
